==> signer-1.101.0-sources.jar: software/amazon/awscdk/services/signer/CfnProfilePermissionProps.java <==
package software.amazon.awscdk.services.signer;

/**
 * Properties for defining a `AWS::Signer::ProfilePermission`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:19.629Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.CfnProfilePermissionProps")
@software.amazon.jsii.Jsii.Proxy(CfnProfilePermissionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnProfilePermissionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Signer::ProfilePermission.Action`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAction();

    /**
     * `AWS::Signer::ProfilePermission.Principal`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPrincipal();

    /**
     * `AWS::Signer::ProfilePermission.ProfileName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProfileName();

    /**
     * `AWS::Signer::ProfilePermission.StatementId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getStatementId();

    /**
     * `AWS::Signer::ProfilePermission.ProfileVersion`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getProfileVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnProfilePermissionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnProfilePermissionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnProfilePermissionProps> {
        private java.lang.String action;
        private java.lang.String principal;
        private java.lang.String profileName;
        private java.lang.String statementId;
        private java.lang.String profileVersion;

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getAction}
         * @param action `AWS::Signer::ProfilePermission.Action`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder action(java.lang.String action) {
            this.action = action;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getPrincipal}
         * @param principal `AWS::Signer::ProfilePermission.Principal`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder principal(java.lang.String principal) {
            this.principal = principal;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getProfileName}
         * @param profileName `AWS::Signer::ProfilePermission.ProfileName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profileName(java.lang.String profileName) {
            this.profileName = profileName;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getStatementId}
         * @param statementId `AWS::Signer::ProfilePermission.StatementId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder statementId(java.lang.String statementId) {
            this.statementId = statementId;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getProfileVersion}
         * @param profileVersion `AWS::Signer::ProfilePermission.ProfileVersion`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profileVersion(java.lang.String profileVersion) {
            this.profileVersion = profileVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnProfilePermissionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnProfilePermissionProps build() {
            return new Jsii$Proxy(action, principal, profileName, statementId, profileVersion);
        }
    }

    /**
     * An implementation for {@link CfnProfilePermissionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnProfilePermissionProps {
        private final java.lang.String action;
        private final java.lang.String principal;
        private final java.lang.String profileName;
        private final java.lang.String statementId;
        private final java.lang.String profileVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.action = software.amazon.jsii.Kernel.get(this, "action", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.principal = software.amazon.jsii.Kernel.get(this, "principal", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.profileName = software.amazon.jsii.Kernel.get(this, "profileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.statementId = software.amazon.jsii.Kernel.get(this, "statementId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.profileVersion = software.amazon.jsii.Kernel.get(this, "profileVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String action, final java.lang.String principal, final java.lang.String profileName, final java.lang.String statementId, final java.lang.String profileVersion) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.action = java.util.Objects.requireNonNull(action, "action is required");
            this.principal = java.util.Objects.requireNonNull(principal, "principal is required");
            this.profileName = java.util.Objects.requireNonNull(profileName, "profileName is required");
            this.statementId = java.util.Objects.requireNonNull(statementId, "statementId is required");
            this.profileVersion = profileVersion;
        }

        @Override
        public final java.lang.String getAction() {
            return this.action;
        }

        @Override
        public final java.lang.String getPrincipal() {
            return this.principal;
        }

        @Override
        public final java.lang.String getProfileName() {
            return this.profileName;
        }

        @Override
        public final java.lang.String getStatementId() {
            return this.statementId;
        }

        @Override
        public final java.lang.String getProfileVersion() {
            return this.profileVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("action", om.valueToTree(this.getAction()));
            data.set("principal", om.valueToTree(this.getPrincipal()));
            data.set("profileName", om.valueToTree(this.getProfileName()));
            data.set("statementId", om.valueToTree(this.getStatementId()));
            if (this.getProfileVersion() != null) {
                data.set("profileVersion", om.valueToTree(this.getProfileVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-signer.CfnProfilePermissionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnProfilePermissionProps.Jsii$Proxy that = (CfnProfilePermissionProps.Jsii$Proxy) o;

            if (!action.equals(that.action)) return false;
            if (!principal.equals(that.principal)) return false;
            if (!profileName.equals(that.profileName)) return false;
            if (!statementId.equals(that.statementId)) return false;
            return this.profileVersion != null ? this.profileVersion.equals(that.profileVersion) : that.profileVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.action.hashCode();
            result = 31 * result + (this.principal.hashCode());
            result = 31 * result + (this.profileName.hashCode());
            result = 31 * result + (this.statementId.hashCode());
            result = 31 * result + (this.profileVersion != null ? this.profileVersion.hashCode() : 0);
            return result;
        }
    }
}

==> signer-1.174.0-sources.jar: software/amazon/awscdk/services/signer/CfnProfilePermissionProps.java <==
package software.amazon.awscdk.services.signer;

/**
 * Properties for defining a `CfnProfilePermission`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.signer.*;
 * CfnProfilePermissionProps cfnProfilePermissionProps = CfnProfilePermissionProps.builder()
 *         .action("action")
 *         .principal("principal")
 *         .profileName("profileName")
 *         .statementId("statementId")
 *         // the properties below are optional
 *         .profileVersion("profileVersion")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-21T22:31:00.798Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.signer.$Module.class, fqn = "@aws-cdk/aws-signer.CfnProfilePermissionProps")
@software.amazon.jsii.Jsii.Proxy(CfnProfilePermissionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnProfilePermissionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The AWS Signer action permitted as part of cross-account permissions.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAction();

    /**
     * The AWS principal receiving cross-account permissions.
     * <p>
     * This may be an IAM role or another AWS account ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPrincipal();

    /**
     * The human-readable name of the signing profile.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProfileName();

    /**
     * A unique identifier for the cross-account permission statement.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getStatementId();

    /**
     * The version of the signing profile.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getProfileVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnProfilePermissionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnProfilePermissionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnProfilePermissionProps> {
        java.lang.String action;
        java.lang.String principal;
        java.lang.String profileName;
        java.lang.String statementId;
        java.lang.String profileVersion;

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getAction}
         * @param action The AWS Signer action permitted as part of cross-account permissions. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder action(java.lang.String action) {
            this.action = action;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getPrincipal}
         * @param principal The AWS principal receiving cross-account permissions. This parameter is required.
         *                  This may be an IAM role or another AWS account ID.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder principal(java.lang.String principal) {
            this.principal = principal;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getProfileName}
         * @param profileName The human-readable name of the signing profile. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profileName(java.lang.String profileName) {
            this.profileName = profileName;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getStatementId}
         * @param statementId A unique identifier for the cross-account permission statement. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder statementId(java.lang.String statementId) {
            this.statementId = statementId;
            return this;
        }

        /**
         * Sets the value of {@link CfnProfilePermissionProps#getProfileVersion}
         * @param profileVersion The version of the signing profile.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder profileVersion(java.lang.String profileVersion) {
            this.profileVersion = profileVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnProfilePermissionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnProfilePermissionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnProfilePermissionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnProfilePermissionProps {
        private final java.lang.String action;
        private final java.lang.String principal;
        private final java.lang.String profileName;
        private final java.lang.String statementId;
        private final java.lang.String profileVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.action = software.amazon.jsii.Kernel.get(this, "action", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.principal = software.amazon.jsii.Kernel.get(this, "principal", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.profileName = software.amazon.jsii.Kernel.get(this, "profileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.statementId = software.amazon.jsii.Kernel.get(this, "statementId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.profileVersion = software.amazon.jsii.Kernel.get(this, "profileVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.action = java.util.Objects.requireNonNull(builder.action, "action is required");
            this.principal = java.util.Objects.requireNonNull(builder.principal, "principal is required");
            this.profileName = java.util.Objects.requireNonNull(builder.profileName, "profileName is required");
            this.statementId = java.util.Objects.requireNonNull(builder.statementId, "statementId is required");
            this.profileVersion = builder.profileVersion;
        }

        @Override
        public final java.lang.String getAction() {
            return this.action;
        }

        @Override
        public final java.lang.String getPrincipal() {
            return this.principal;
        }

        @Override
        public final java.lang.String getProfileName() {
            return this.profileName;
        }

        @Override
        public final java.lang.String getStatementId() {
            return this.statementId;
        }

        @Override
        public final java.lang.String getProfileVersion() {
            return this.profileVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("action", om.valueToTree(this.getAction()));
            data.set("principal", om.valueToTree(this.getPrincipal()));
            data.set("profileName", om.valueToTree(this.getProfileName()));
            data.set("statementId", om.valueToTree(this.getStatementId()));
            if (this.getProfileVersion() != null) {
                data.set("profileVersion", om.valueToTree(this.getProfileVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-signer.CfnProfilePermissionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnProfilePermissionProps.Jsii$Proxy that = (CfnProfilePermissionProps.Jsii$Proxy) o;

            if (!action.equals(that.action)) return false;
            if (!principal.equals(that.principal)) return false;
            if (!profileName.equals(that.profileName)) return false;
            if (!statementId.equals(that.statementId)) return false;
            return this.profileVersion != null ? this.profileVersion.equals(that.profileVersion) : that.profileVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.action.hashCode();
            result = 31 * result + (this.principal.hashCode());
            result = 31 * result + (this.profileName.hashCode());
            result = 31 * result + (this.statementId.hashCode());
            result = 31 * result + (this.profileVersion != null ? this.profileVersion.hashCode() : 0);
            return result;
        }
    }
}
